==> mediawiki-1.12.4.tbz: www/mediawiki/languages/messages/MessagesTn.php <==
<?php
/** Tswana (Setswana)
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Hakka
 */

$messages = array(
# Dates
'sunday'        => 'Tshipi',
'monday'        => 'Mosupologo',
'tuesday'       => 'Labobedi',
'wednesday'     => 'Laboraro',
'thursday'      => 'Labone',
'friday'        => 'Labotlhano',
'saturday'      => 'Matlhatso',
'january'       => 'Firikgong',
'february'      => 'Tlhakole',
'march'         => 'Mopitlo',
'april'         => 'Moranang',
'may_long'      => 'Motsheganong',
'june'          => 'Seetebosigo',
'july'          => 'Phukwi',
'august'        => 'Phatwe',
'september'     => 'Lwetse',
'october'       => 'Phalane',
'november'      => 'Ngwanatsele',
'december'      => 'Sedimonthole',
'january-gen'   => 'Firikgong',
'february-gen'  => 'Tlhakole',
'march-gen'     => 'Mopitlo',
'april-gen'     => 'Moranang',
'may-gen'       => 'Motsheganong',
'june-gen'      => 'Seetebosigo',
'july-gen'      => 'Phukwi',
'august-gen'    => 'Phatwe',
'september-gen' => 'Lwetse',
'october-gen'   => 'Phalane',
'november-gen'  => 'Ngwanatsele',
'december-gen'  => 'Sedimonthole',

'cancel'     => 'Sutlha',
'mytalk'     => 'Puo yame',
'navigation' => 'Tsweletso',

'help'             => 'Thuso',
'search'           => 'Senka',
'searchbutton'     => 'Senka',
'go'               => 'Tsamaya',
'searcharticle'    => 'Tsamaya',
'history_short'    => 'Ditso',
'printableversion' => 'Mokwalo o o ka gatisiwang motlhofo',
'permalink'        => 'Kgolagano ya sennelaruri',
'edit'             => 'Baakanya',
'delete'           => 'Sutlha',
'protect'          => 'Sireletsa',
'talk'             => 'Puisano',
'toolbox'          => 'Lebokoso la dithulusu',
'otherlanguages'   => 'Ka dipuo di sele',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents' => 'Ditiragalo tsa sešeng',
'disclaimers'   => 'Tlhapa diatla',
'edithelp'      => 'Thuso ya go fetola',
'mainpage'      => 'Tsebe ya konokono',
'portal'        => 'Patlelo ya setšhaba',
'portal-url'    => 'Project:Patlelo ya setšhaba',
'privacy'       => 'Melawana ya sephiri',
'sitesupport'   => 'Dimpho',

'youhavenewmessages'      => 'O na le $1 ($2).',
'newmessageslink'         => 'molaetsa o moša',
'youhavenewmessagesmulti' => 'O na le molaetsa o moša mo $1',
'editsection'             => 'baakanya',
'editold'                 => 'baakanya',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Mokwalo',
'nstab-mediawiki' => 'Molaetsa',

# General errors
'viewsource' => 'Lebelela motswedi',

# Login and logout pages
'welcomecreation'    => '== Amogelesega, $1! == 

O ipuletse akhaonte. O seka wa lebala go fetola tse o di dikgatlhegelo tsa gago tsa {{SITENAME}}.',
'yourname'           => 'Leina la modirisi:',
'yourpassword'       => 'Selotlolo sa sephiri:',
'yourpasswordagain'  => 'Kwala selotlolo sa gago sa sephiri gape:',
'remembermypassword' => 'Gakologelwa ikwadiso yame mo khompiutareng e',
'login'              => 'Ikwadise',
'userlogin'          => 'Ikwadise / ipulela tsebe',
'logout'             => 'Tswala',
'userlogout'         => 'Tswala',
'notloggedin'        => 'Ga o a ikwadisa',
'createaccount'      => 'Ipulela tsebe',
'youremail'          => 'E-mail:',
'username'           => 'Leina la modirisi:',

# Edit pages
'summary'            => 'Tshoboko',
'minoredit'          => 'Se ke paakanyo e potlana',
'watchthis'          => 'Lebelela tsebe e',
'savearticle'        => 'Boloka tsebe',
'showpreview'        => 'Supa gore go tlaa lebega jang',
'showdiff'           => 'Supa diphetogo',
'whitelistedittitle' => 'Ikwadiso e a tlhokafala fa o batla go baakanya sengwe',

# History pages
'currentrev'          => 'Dipaakanyo tsa sešeng',
'currentrevisionlink' => 'Dipaakanyo tsa sešeng',

# Preferences page
'mypreferences' => 'Dikgatlhegelo tsa me',

# Recent changes
'recentchanges' => 'Diphetogo tsa sešeng',

# Recent changes linked
'recentchangeslinked' => 'Diphetogo tse di tsamaelanang',

# Upload
'upload'          => 'Tsenya mokwalo o o tswang kwantle',
'uploadbtn'       => 'Tsenya mokwalo o o tswang kwantle',
'watchthisupload' => 'Lebelela tsebe e',

# Random page
'randompage' => 'Tsebe e e sa tlhomamang',

# Miscellaneous special pages
'specialpages' => 'Diphetogo tse di faphegileng',
'move'         => 'Suta',
'movethispage' => 'Sutisa tsebe e',

# Watchlist
'mywatchlist'   => 'Mafoko a ke a etseng tlhoko',
'watchnologin'  => 'Ga o a ikwadisa',
'watch'         => 'Lebelela',
'watchthispage' => 'Lebelela tsebe e',

# Undelete
'undelete-search-submit' => 'Senka',

# Contributions
'mycontris' => 'Seabe same',

# What links here
'whatlinkshere' => 'Ke eng se se gokaganang fa',

# Move page
'movepage'    => 'Sutisa tsebe',
'movearticle' => 'Sutisa tsebe:',
'movenologin' => 'Ga o a ikwadisa',
'movepagebtn' => 'Sutisa tsebe',
'movedto'     => 'sutela kwa',
'1movedto2'   => '[[$1]] o sutisediwa kwa go [[$2]]',
'movereason'  => 'Lebaka:',

# Namespace 8 related
'allmessages' => 'Melaetsa ya maranyane',

);

==> mediawiki-1.15.5.tbz: www/mediawiki/languages/messages/MessagesTn.php <==
<?php
/** Tswana (Setswana)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Cbrown1023
 * @author Hakka
 */

$messages = array(
# Dates
'sunday'        => 'Tshipi',
'monday'        => 'Mosupologo',
'tuesday'       => 'Labobedi',
'wednesday'     => 'Laboraro',
'thursday'      => 'Labone',
'friday'        => 'Labotlhano',
'saturday'      => 'Matlhatso',
'january'       => 'Firikgong',
'february'      => 'Tlhakole',
'march'         => 'Mopitlo',
'april'         => 'Moranang',
'may_long'      => 'Motsheganong',
'june'          => 'Seetebosigo',
'july'          => 'Phukwi',
'august'        => 'Phatwe',
'september'     => 'Lwetse',
'october'       => 'Phalane',
'november'      => 'Ngwanatsele',
'december'      => 'Sedimonthole',
'january-gen'   => 'Firikgong',
'february-gen'  => 'Tlhakole',
'march-gen'     => 'Mopitlo',
'april-gen'     => 'Moranang',
'may-gen'       => 'Motsheganong',
'june-gen'      => 'Seetebosigo',
'july-gen'      => 'Phukwi',
'august-gen'    => 'Phatwe',
'september-gen' => 'Lwetse',
'october-gen'   => 'Phalane',
'november-gen'  => 'Ngwanatsele',
'december-gen'  => 'Sedimonthole',

'cancel'     => 'Sutlha',
'mytalk'     => 'Puo yame',
'navigation' => 'Tsweletso',

'help'             => 'Thuso',
'search'           => 'Senka',
'searchbutton'     => 'Senka',
'go'               => 'Tsamaya',
'searcharticle'    => 'Tsamaya',
'history_short'    => 'Ditso',
'printableversion' => 'Mokwalo o o ka gatisiwang motlhofo',
'permalink'        => 'Kgolagano ya sennelaruri',
'edit'             => 'Baakanya',
'delete'           => 'Sutlha',
'protect'          => 'Sireletsa',
'talk'             => 'Puisano',
'toolbox'          => 'Lebokoso la dithulusu',
'otherlanguages'   => 'Ka dipuo di sele',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'currentevents'        => 'Ditiragalo tsa sešeng',
'disclaimers'          => 'Tlhapa diatla',
'edithelp'             => 'Thuso ya go fetola',
'mainpage'             => 'Tsebe ya konokono',
'mainpage-description' => 'Tsebe ya konokono',
'portal'               => 'Patlelo ya setšhaba',
'portal-url'           => 'Project:Patlelo ya setšhaba',
'privacy'              => 'Melawana ya sephiri',

'youhavenewmessages'      => 'O na le $1 ($2).',
'newmessageslink'         => 'molaetsa o moša',
'youhavenewmessagesmulti' => 'O na le molaetsa o moša mo $1',
'editsection'             => 'baakanya',
'editold'                 => 'baakanya',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Mokwalo',
'nstab-mediawiki' => 'Molaetsa',

# General errors
'viewsource' => 'Lebelela motswedi',

# Login and logout pages
'welcomecreation'    => '== Amogelesega, $1! == 

O ipuletse akhaonte. O seka wa lebala go fetola tse o di dikgatlhegelo tsa gago tsa {{SITENAME}}.',
'yourname'           => 'Leina la modirisi:',
'yourpassword'       => 'Selotlolo sa sephiri:',
'yourpasswordagain'  => 'Kwala selotlolo sa gago sa sephiri gape:',
'remembermypassword' => 'Gakologelwa ikwadiso yame mo khompiutareng e',
'login'              => 'Ikwadise',
'userlogin'          => 'Ikwadise / ipulela tsebe',
'logout'             => 'Tswala',
'userlogout'         => 'Tswala',
'notloggedin'        => 'Ga o a ikwadisa',
'createaccount'      => 'Ipulela tsebe',
'youremail'          => 'E-mail:',
'username'           => 'Leina la modirisi:',

# Edit pages
'summary'            => 'Tshoboko:',
'minoredit'          => 'Se ke paakanyo e potlana',
'watchthis'          => 'Lebelela tsebe e',
'savearticle'        => 'Boloka tsebe',
'showpreview'        => 'Supa gore go tlaa lebega jang',
'showdiff'           => 'Supa diphetogo',
'whitelistedittitle' => 'Ikwadiso e a tlhokafala fa o batla go baakanya sengwe',

# History pages
'currentrev'          => 'Dipaakanyo tsa sešeng',
'currentrevisionlink' => 'Dipaakanyo tsa sešeng',

# Preferences page
'mypreferences' => 'Dikgatlhegelo tsa me',

# Recent changes
'recentchanges' => 'Diphetogo tsa sešeng',

# Recent changes linked
'recentchangeslinked' => 'Diphetogo tse di tsamaelanang',

# Upload
'upload'          => 'Tsenya mokwalo o o tswang kwantle',
'uploadbtn'       => 'Tsenya mokwalo o o tswang kwantle',
'watchthisupload' => 'Lebelela tsebe e',

# Random page
'randompage' => 'Tsebe e e sa tlhomamang',

# Miscellaneous special pages
'move'         => 'Suta',
'movethispage' => 'Sutisa tsebe e',

# Watchlist
'mywatchlist'   => 'Mafoko a ke a etseng tlhoko',
'watchnologin'  => 'Ga o a ikwadisa',
'watch'         => 'Lebelela',
'watchthispage' => 'Lebelela tsebe e',

# Protect
'prot_1movedto2' => '[[$1]] o sutisediwa kwa go [[$2]]',

# Undelete
'undelete-search-submit' => 'Senka',

# Contributions
'mycontris' => 'Seabe same',

# What links here
'whatlinkshere' => 'Ke eng se se gokaganang fa',

# Move page
'move-page-legend' => 'Sutisa tsebe',
'movearticle'      => 'Sutisa tsebe:',
'movenologin'      => 'Ga o a ikwadisa',
'movepagebtn'      => 'Sutisa tsebe',
'movedto'          => 'sutela kwa',
'1movedto2'        => '[[$1]] o sutisediwa kwa go [[$2]]',
'movereason'       => 'Lebaka:',

# Namespace 8 related
'allmessages' => 'Melaetsa ya maranyane',

# Special:SpecialPages
'specialpages' => 'Diphetogo tse di faphegileng',

);
